==> zio-aws-amplifyuibuilder_2.12-5.17.157.2-sources.jar: zio/aws/amplifyuibuilder/model/package.scala <==
package zio.aws.amplifyuibuilder
import zio.aws.amplifyuibuilder.model.primitives.{TagValue, TagKey}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.amplifyuibuilder.model.primitives.ListThemesLimit.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ComponentName extends Subtype[String]
    type ComponentName =
      zio.aws.amplifyuibuilder.model.primitives.ComponentName.Type
    object ComponentType extends Subtype[String]
    type ComponentType =
      zio.aws.amplifyuibuilder.model.primitives.ComponentType.Type
    type Integer = Int
    object ListComponentsLimit extends Subtype[Int]
    type ListComponentsLimit =
      zio.aws.amplifyuibuilder.model.primitives.ListComponentsLimit.Type
    object ListThemesLimit extends Subtype[Int]
    type ListThemesLimit =
      zio.aws.amplifyuibuilder.model.primitives.ListThemesLimit.Type
    object SyntheticExchangeCodeForTokenRequestBodyString
        extends Subtype[String]
    type SyntheticExchangeCodeForTokenRequestBodyString =
      zio.aws.amplifyuibuilder.model.primitives.SyntheticExchangeCodeForTokenRequestBodyString.Type
    object SyntheticExchangeCodeForTokenResponseString extends Subtype[String]
    type SyntheticExchangeCodeForTokenResponseString =
      zio.aws.amplifyuibuilder.model.primitives.SyntheticExchangeCodeForTokenResponseString.Type
    object SyntheticRefreshTokenRequestBodyString extends Subtype[String]
    type SyntheticRefreshTokenRequestBodyString =
      zio.aws.amplifyuibuilder.model.primitives.SyntheticRefreshTokenRequestBodyString.Type
    object SyntheticRefreshTokenResponseString extends Subtype[String]
    type SyntheticRefreshTokenResponseString =
      zio.aws.amplifyuibuilder.model.primitives.SyntheticRefreshTokenResponseString.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.amplifyuibuilder.model.primitives.SyntheticTimestamp_date_time.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.amplifyuibuilder.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.amplifyuibuilder.model.primitives.TagValue.Type
    object ThemeName extends Subtype[String]
    type ThemeName = zio.aws.amplifyuibuilder.model.primitives.ThemeName.Type
    object Uuid extends Subtype[String]
    type Uuid = zio.aws.amplifyuibuilder.model.primitives.Uuid.Type
  }
  type ComponentBindingProperties =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentBindingPropertiesValue]
  type ComponentChildList = List[zio.aws.amplifyuibuilder.model.ComponentChild]
  type ComponentCollectionProperties =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentDataConfiguration]
  type ComponentEvents =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentEvent]
  type ComponentList = List[zio.aws.amplifyuibuilder.model.Component]
  type ComponentOverrides = Map[String, Map[String, String]]
  type ComponentOverridesValue = Map[String, String]
  type ComponentProperties =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentProperty]
  type ComponentPropertyList =
    List[zio.aws.amplifyuibuilder.model.ComponentProperty]
  type ComponentSummaryList =
    List[zio.aws.amplifyuibuilder.model.ComponentSummary]
  type ComponentVariantValues = Map[String, String]
  type ComponentVariants = List[zio.aws.amplifyuibuilder.model.ComponentVariant]
  type FormBindings =
    Map[String, zio.aws.amplifyuibuilder.model.FormBindingElement]
  type IdentifierList = List[String]
  type PredicateList = List[zio.aws.amplifyuibuilder.model.Predicate]
  type SortPropertyList = List[zio.aws.amplifyuibuilder.model.SortProperty]
  type Tags = Map[TagKey, TagValue]
  type ThemeList = List[zio.aws.amplifyuibuilder.model.Theme]
  type ThemeSummaryList = List[zio.aws.amplifyuibuilder.model.ThemeSummary]
  type ThemeValuesList = List[zio.aws.amplifyuibuilder.model.ThemeValues]
}

==> zio-aws-amplifyuibuilder_2.12-5.17.170.1-sources.jar: zio/aws/amplifyuibuilder/model/package.scala <==
package zio.aws.amplifyuibuilder
import zio.aws.amplifyuibuilder.model.primitives.{TagValue, TagKey}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.amplifyuibuilder.model.primitives.ListThemesLimit.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ComponentName extends Subtype[String]
    type ComponentName =
      zio.aws.amplifyuibuilder.model.primitives.ComponentName.Type
    object ComponentType extends Subtype[String]
    type ComponentType =
      zio.aws.amplifyuibuilder.model.primitives.ComponentType.Type
    type Integer = Int
    object ListComponentsLimit extends Subtype[Int]
    type ListComponentsLimit =
      zio.aws.amplifyuibuilder.model.primitives.ListComponentsLimit.Type
    object ListThemesLimit extends Subtype[Int]
    type ListThemesLimit =
      zio.aws.amplifyuibuilder.model.primitives.ListThemesLimit.Type
    object SensitiveString extends Subtype[String]
    type SensitiveString =
      zio.aws.amplifyuibuilder.model.primitives.SensitiveString.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.amplifyuibuilder.model.primitives.SyntheticTimestamp_date_time.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.amplifyuibuilder.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.amplifyuibuilder.model.primitives.TagValue.Type
    object ThemeName extends Subtype[String]
    type ThemeName = zio.aws.amplifyuibuilder.model.primitives.ThemeName.Type
    object Uuid extends Subtype[String]
    type Uuid = zio.aws.amplifyuibuilder.model.primitives.Uuid.Type
  }
  type ComponentBindingProperties =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentBindingPropertiesValue]
  type ComponentChildList = List[zio.aws.amplifyuibuilder.model.ComponentChild]
  type ComponentCollectionProperties =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentDataConfiguration]
  type ComponentEvents =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentEvent]
  type ComponentList = List[zio.aws.amplifyuibuilder.model.Component]
  type ComponentOverrides = Map[String, Map[String, String]]
  type ComponentOverridesValue = Map[String, String]
  type ComponentProperties =
    Map[String, zio.aws.amplifyuibuilder.model.ComponentProperty]
  type ComponentPropertyList =
    List[zio.aws.amplifyuibuilder.model.ComponentProperty]
  type ComponentSummaryList =
    List[zio.aws.amplifyuibuilder.model.ComponentSummary]
  type ComponentVariantValues = Map[String, String]
  type ComponentVariants = List[zio.aws.amplifyuibuilder.model.ComponentVariant]
  type FormBindings =
    Map[String, zio.aws.amplifyuibuilder.model.FormBindingElement]
  type IdentifierList = List[String]
  type PredicateList = List[zio.aws.amplifyuibuilder.model.Predicate]
  type SortPropertyList = List[zio.aws.amplifyuibuilder.model.SortProperty]
  type Tags = Map[TagKey, TagValue]
  type ThemeList = List[zio.aws.amplifyuibuilder.model.Theme]
  type ThemeSummaryList = List[zio.aws.amplifyuibuilder.model.ThemeSummary]
  type ThemeValuesList = List[zio.aws.amplifyuibuilder.model.ThemeValues]
}
